@@ -59,7 +59,7 @@ class Exceptions:
 
 class EBSClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.56/reference/services/ebs.html#EBS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html)
     """
 
@@ -75,7 +75,7 @@ class EBSClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.56/reference/services/ebs.html#EBS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#can_paginate)
         """
 
@@ -84,29 +84,29 @@ class EBSClient(BaseClient):
         *,
         SnapshotId: str,
         ChangedBlocksCount: int,
-        Checksum: str = None,
-        ChecksumAlgorithm: Literal["SHA256"] = None,
-        ChecksumAggregationMethod: Literal["LINEAR"] = None
+        Checksum: str = ...,
+        ChecksumAlgorithm: Literal["SHA256"] = ...,
+        ChecksumAggregationMethod: Literal["LINEAR"] = ...
     ) -> CompleteSnapshotResponseTypeDef:
         """
         Seals and completes the snapshot after all of the required blocks of data have
         been written to it.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.complete_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.56/reference/services/ebs.html#EBS.Client.complete_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#complete_snapshot)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.56/reference/services/ebs.html#EBS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#generate_presigned_url)
         """
 
@@ -116,7 +116,7 @@ class EBSClient(BaseClient):
         """
         Returns the data in a block in an Amazon Elastic Block Store snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.get_snapshot_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.56/reference/services/ebs.html#EBS.Client.get_snapshot_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#get_snapshot_block)
         """
 
@@ -124,16 +124,16 @@ class EBSClient(BaseClient):
         self,
         *,
         SecondSnapshotId: str,
-        FirstSnapshotId: str = None,
-        NextToken: str = None,
-        MaxResults: int = None,
-        StartingBlockIndex: int = None
+        FirstSnapshotId: str = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        StartingBlockIndex: int = ...
     ) -> ListChangedBlocksResponseTypeDef:
         """
         Returns information about the blocks that are different between two Amazon
         Elastic Block Store snapshots of the same volume/snapshot lineage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.list_changed_blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.56/reference/services/ebs.html#EBS.Client.list_changed_blocks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list_changed_blocks)
         """
 
@@ -141,14 +141,14 @@ class EBSClient(BaseClient):
         self,
         *,
         SnapshotId: str,
-        NextToken: str = None,
-        MaxResults: int = None,
-        StartingBlockIndex: int = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        StartingBlockIndex: int = ...
     ) -> ListSnapshotBlocksResponseTypeDef:
         """
         Returns information about the blocks in an Amazon Elastic Block Store snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.56/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list_snapshot_blocks)
         """
 
@@ -161,12 +161,12 @@ class EBSClient(BaseClient):
         DataLength: int,
         Checksum: str,
         ChecksumAlgorithm: Literal["SHA256"],
-        Progress: int = None
+        Progress: int = ...
     ) -> PutSnapshotBlockResponseTypeDef:
         """
         Writes a block of data to a snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.put_snapshot_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.56/reference/services/ebs.html#EBS.Client.put_snapshot_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#put_snapshot_block)
         """
 
@@ -174,17 +174,17 @@ class EBSClient(BaseClient):
         self,
         *,
         VolumeSize: int,
-        ParentSnapshotId: str = None,
-        Tags: Sequence["TagTypeDef"] = None,
-        Description: str = None,
-        ClientToken: str = None,
-        Encrypted: bool = None,
-        KmsKeyArn: str = None,
-        Timeout: int = None
+        ParentSnapshotId: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        Description: str = ...,
+        ClientToken: str = ...,
+        Encrypted: bool = ...,
+        KmsKeyArn: str = ...,
+        Timeout: int = ...
     ) -> StartSnapshotResponseTypeDef:
         """
         Creates a new Amazon EBS snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/ebs.html#EBS.Client.start_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.56/reference/services/ebs.html#EBS.Client.start_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#start_snapshot)
         """
